```
Usage: vcd gateway services firewall create [OPTIONS] <gateway name>

Options:
  --name <firewall rule name>     firewall rule name  [required]
  --action <accept/deny>          action. possible values accept/deny
  --type <str>                    type
  --enabled / --disabled          enable
  --logging-enabled / --logging-disabled
                                  logging enabled
  -h, --help                      Show this message and exit.

```
